.. redirect-from:: /users/prev_whats_new/github_stats_3.3.4

.. _github-stats-3-3-4:

GitHub statistics for 3.3.4 (Jan 28, 2021)
==========================================

GitHub statistics for 2020/11/12 (tag: v3.3.3) - 2021/01/28

These lists are automatically generated, and may be incomplete or contain duplicates.

We closed 2 issues and merged 20 pull requests.
The full list can be seen `on GitHub <https://github.com/matplotlib/matplotlib/milestone/60?closed=1>`__

The following 7 authors contributed 43 commits.

* Antony Lee
* David Stansby
* Elliott Sales de Andrade
* Jody Klymak
* Mark Harfouche
* Thomas A Caswell
* Tim Hoffmann

GitHub issues and pull requests:

Pull Requests (20):

* :ghpull:`19386`: Backport PR #19238 on branch v3.3.x (Fix build with LTO disabled in environment)
* :ghpull:`19238`: Fix build with LTO disabled in environment
* :ghpull:`19382`: Backport PR #19052 on branch v3.3.x (Always pass integers to wx.Size.)
* :ghpull:`19377`: Backport PR #19371 on branch v3.3.x (Fix specgram test on NumPy 1.20.)
* :ghpull:`19371`: Fix specgram test on NumPy 1.20.
* :ghpull:`19305`: Backport PR #19301 on branch v3.3.x
* :ghpull:`19301`: Fix several CI issues
* :ghpull:`19269`: Backport PR #19266 on branch v3.3.x (Don't update homebrew on GitHub Actions)
* :ghpull:`19266`: Don't update homebrew on GitHub Actions
* :ghpull:`19252`: Backport PR #19245 on branch v3.3.x (handle usecase where QT_API is specified with some capitals)
* :ghpull:`19245`: handle usecase where QT_API is specified with some capitals
* :ghpull:`19143`: Backport PR #19131 on branch v3.3.x (Fix WebAgg initialization)
* :ghpull:`19115`: Backport PR #19108 on branch v3.3.x
* :ghpull:`19165`: Backport PR #19163 on branch v3.3.x (Ignore missing _FancyAxislineStyle doc targets.)
* :ghpull:`19163`: Ignore missing _FancyAxislineStyle doc targets.
* :ghpull:`19131`: Fix WebAgg initialization
* :ghpull:`19052`: Always pass integers to wx.Size.
* :ghpull:`19108`: Fix failing animation test with pytest 6.2.
* :ghpull:`19062`: Backport PR #19036 on branch v3.3.x
* :ghpull:`19036`: Start testing using GitHub Actions

Issues (2):

* :ghissue:`19227`: Matplotlib generates invalid ft2font if -fno-lto gcc CFLAGS used
* :ghissue:`19129`: webAgg example broken - maybe mpl.js broken?
